==> ClanLib-1.0.0.tgz: ClanLib-1.0.0/Sources/Core/System/Win32/thread_win32.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2005 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
**    (if your name is missing here, please add it)
*/

#ifndef header_thread_win32
#define header_thread_win32

#if _MSC_VER > 1000
#pragma once
#endif

#include "API/Core/System/thread.h"
#include <windows.h>

class CL_Thread_Generic
{
//! Attributes:
public:
	static unsigned long __stdcall func_proxy(void *arg);

	HANDLE thread_handle;

	DWORD thread_id;
	
	CL_Runnable *runnable;
	
	bool delete_runnable;
	
	int ref_count;
};

class CL_ThreadId_Generic
{
public:
	DWORD thread_id;
};

#endif

==> ClanLib-2.2.12.tgz: ClanLib-2.2.12/Sources/Core/System/Win32/thread_win32.h <==
/*
**  ClanLib SDK
**  Copyright (c) 1997-2011 The ClanLib Team
**
**  This software is provided 'as-is', without any express or implied
**  warranty.  In no event will the authors be held liable for any damages
**  arising from the use of this software.
**
**  Permission is granted to anyone to use this software for any purpose,
**  including commercial applications, and to alter it and redistribute it
**  freely, subject to the following restrictions:
**
**  1. The origin of this software must not be misrepresented; you must not
**     claim that you wrote the original software. If you use this software
**     in a product, an acknowledgment in the product documentation would be
**     appreciated but is not required.
**  2. Altered source versions must be plainly marked as such, and must not be
**     misrepresented as being the original software.
**  3. This notice may not be removed or altered from any source distribution.
**
**  Note: Some of the libraries ClanLib may link to may have additional
**  requirements or restrictions.
**
**  File Author(s):
**
**    Magnus Norddahl
*/

#pragma once


#include "../thread_impl.h"

class CL_Thread_Win32 : public CL_Thread_Impl
{
/// \name Construction
/// \{

public:
	CL_Thread_Win32();

	~CL_Thread_Win32();


/// \}
/// \name Attributes
/// \{

public:

/// \}
/// \name Operations
/// \{

public:
	void start(CL_Runnable *runnable);

	void join();

	void kill();

/// \}
/// \name Implementation
/// \{

private:
	static unsigned __stdcall thread_main(void *data);

	HANDLE handle;
/// \}
};
